{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#Dockstore.cwl",
            "label": "CGP file checksum generator",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-chksum/status)\nA Docker container for producing file md5sum and sha512sum. See the [dockstore-cgp-chksum](https://github.com/cancerit/dockstore-cgp-chksum) website for more information.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-chksum:0.4.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-A",
                        "position": 5
                    },
                    "doc": "Flag to suppress all curl exit status",
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_all_curl_exits"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "prefix": "-E",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional curl exit codes to suppress",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_curl_exits"
                },
                {
                    "type": "File",
                    "doc": "file to have checksum generated from",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "use as chksum output instead of generating a new one.",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-j",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-p",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-H",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_headers"
                }
            ],
            "baseCommand": [
                "/opt/wtsi-cgp/bin/sums2json.sh"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "yaobo.xu@sanger.ac.uk",
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yx2@sanger.ac.uk"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).check_sums.json"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).server_response.txt"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/server_response"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": true
                    },
                    "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl/file_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "shellQuote": true
                    },
                    "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl/in_json"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_json.basename)"
                    },
                    "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl/out_json"
                }
            ],
            "baseCommand": [
                "bash",
                "-c",
                "set -x; in=$0; json=$1; bz2_pattern=\"*.bz2\"; if [[ $in == $bz2_pattern ]]; then echo 'file_name is bz2, I will have no output'; else echo 'file_name is not bz2, I will output the input json file'; cp $json $(basename $json); fi"
            ],
            "id": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl"
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "If Input file 1 has bz2 extension generate md5sum from input file 2 else returns input chksum json",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/in_1"
                },
                {
                    "type": "File",
                    "id": "#main/in_2"
                },
                {
                    "type": "File",
                    "id": "#main/in_json"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/chksum/chksum_json",
                    "id": "#main/chksum_json"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/in_2",
                            "id": "#main/chksum/in_file"
                        },
                        {
                            "source": "#main/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/out_json",
                            "id": "#main/chksum/in_json"
                        }
                    ],
                    "out": [
                        "#main/chksum/chksum_json"
                    ],
                    "run": "#Dockstore.cwl",
                    "id": "#main/chksum"
                },
                {
                    "in": [
                        {
                            "source": "#main/in_1",
                            "id": "#main/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/file_name"
                        },
                        {
                            "source": "#main/in_json",
                            "id": "#main/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/in_json"
                        }
                    ],
                    "out": [
                        "#main/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output/out_json"
                    ],
                    "run": "#if_file_name_is_bz2_then_return_null_else_return_in_json_to_output.cwl",
                    "id": "#main/if_file_name_is_bz2_then_return_null_else_return_in_json_to_output"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
